<?php

namespace Drupal\date_range_availability;

use Twig\TwigFunction;
use Twig\Extension\AbstractExtension;
use Drupal\node\Entity\Node;

/**
 * Class NodeAvailabilityFunction.
 */
class NodeAvailabilityFunction extends AbstractExtension {

  /**
   * Custom twig functions.
   */
  public function getFunctions() {
    return [
      new TwigFunction('node_availability', [$this, 'getNodeAvailability']),
    ];
  }

  public function getNodeAvailability($nid, $field_date) {
    $node_availability = '';
    $node_availability_class = '';
    $node = Node::load($nid);
    $expire_date = 0;
    $start_date = 0;
    $current_date = \Drupal::time()->getCurrentTime();
    $start_date = $node->get($field_date)->value ? strtotime($node->get($field_date)->value) : 0;
    $expire_date = $node->get($field_date)->end_value ? strtotime($node->get($field_date)->end_value) : 0;

    if ($node->isPublished()) {
      if ($expire_date != 0 && $current_date < $start_date) {
        $node_availability_class = 'soon-label';
        $node_availability = t('Coming Soon');
      } elseif ($expire_date != 0 && $current_date > $start_date && $current_date < $expire_date) {
        $node_availability_class = 'available-label';
        $node_availability = t('Available');
      } elseif ($expire_date != 0 && $current_date > $expire_date) {
        $node_availability_class = 'unavailable-label';
        $node_availability = t('Unavailable');
      }
    }
    return [
      'label' => $node_availability,
      'label_class' => $node_availability_class,
    ];
  }

}
