<?php

namespace Drupal\date_range_availability\Plugin\views\field;

use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\views\ResultRow;

/**
 * A handler to provide a field that displays the total number of learners in a pathway.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("node_availability")
 */
class NodeAvailability extends FieldPluginBase {
  /**
   * {@inheritdoc}
   */
  public function query()
  {
    // Do nothing -- to override the parent query.
  }
   /**
   * Define the available options
   * @return array
   */
  protected function defineOptions()
  {
    $options = parent::defineOptions();
    $options['field_date'] = ['default' => ''];

    return $options;
  }


  /**
   * Provide the options form.
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state)
  {
    $form['field_date'] = array(
      '#title' => $this->t('machine name of the date range field'),
      '#type' => 'textfield',
      '#description' => $this->t('Enter the machine name of the date field (e.g., "field_date").'),
      '#default_value' => $this->options['field_date'],
      '#required' => TRUE,
    );

    parent::buildOptionsForm($form, $form_state);
  }
  
  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values)
  {
    $field_date = $this->options['field_date'];
    $node = $this->getEntity($values);
    $node_availability = '';
    $current_date = \Drupal::time()->getCurrentTime();
    $start_date = $node->get($field_date)->value ? strtotime($node->get($field_date)->value) : 0;
    $expire_date = $node->get($field_date)->end_value ? strtotime($node->get($field_date)->end_value) : 0;

    if ($expire_date != 0 && $current_date < $start_date) {
      $node_availability = t('Coming Soon');
    } elseif ($expire_date != 0 && $current_date > $start_date && $current_date < $expire_date) {
      $node_availability = t('Available');
    } elseif ($expire_date != 0 && $current_date > $expire_date) {
      $node_availability = t('Unavailable');
    }
    return $node_availability;
  }
}
